/*
 * (C) Copyright 2011
 * CompuLab, Ltd., <www.compulab.co.il>
 * Ilya Ledvich <ilya@compulab.co.il>
 * Igor Grinberg < grinberg@compulab.co.il>
 *
 * X-Loader Configuation settings for the CM-T3X board family.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.
 */

#ifndef __CONFIG_H
#define __CONFIG_H

/* serial printf facility takes about 3.5K */
#define CFG_PRINTF

/* Debug flag */
#define CM_T3X_DEBUG	0

/*
 * High Level Configuration Options
 */
#define CONFIG_ARMCORTEXA8	1	/* This is an ARM V7 CPU core */
#define CONFIG_OMAP		1	/* in a TI OMAP core */
#define CONFIG_OMAP34XX		1	/* which is OMAP34XX */
#define CONFIG_CM_T3X		1	/* working with CM-T3X boards */

#define CONFIG_MMC		1
#if defined(CONFIG_MMC)
#define CFG_CMD_MMC		1
#define CFG_CMD_FAT		1
#endif

#include <asm/arch/cpu.h>	/* get chip and board defs */

/* uncomment it if you need timer based udelay(). it takes about 250 bytes */
/* #define CFG_UDELAY */

#define PRCM_CLK_CFG2_332MHZ	1	/* VDD2=1.15v - 166MHz DDR */
/* #define PRCM_CLK_CFG2_266MHZ	1	/\* VDD2=1.15v - 133MHz DDR *\/ */
#define PRCM_PCLK_OPP2		1	/* ARM=381MHz - VDD1=1.20v */

/* The actual register values are defined in u-boot- mem.h */
/* SDRAM Bank Allocation method */
#define SDRC_R_B_C	1
#define DRAM_BASE	OMAP34XX_SDRC_CS0

#ifdef CFG_PRINTF
#define CFG_NS16550
#define CFG_NS16550_SERIAL
#define CFG_NS16550_REG_SIZE	(-4)
#define CFG_NS16550_CLK		(48000000)
#define CFG_NS16550_COM3	OMAP34XX_UART3

/*
 * select serial console configuration
 */
#define CONFIG_SERIAL3		3		/* UART3 on CM-T3X */
#define CONFIG_CONS_INDEX	CONFIG_SERIAL3

#define CONFIG_BAUDRATE		115200
#define CFG_PBSIZE		256
#endif /* CFG_PRINTF */

/*
 * Miscellaneous configurable options
 */
#define CFG_LOADADDR		0x80008000

#undef	CFG_CLKS_IN_HZ		/* everything, incl board info, in Hz */

/*-----------------------------------------------------------------------
 * Stack sizes
 *
 * The stack sizes are set up in start.S using the settings below
 */
#define CONFIG_STACKSIZE	(128*1024)	/* regular stack */

/*-----------------------------------------------------------------------
 * Board NAND Info.
 */

#define NAND_BASE_ADR		NAND_BASE	/* NAND flash */
#define OMAP34XX_GPMC_CS0_SIZE	GPMC_SIZE_128M

/* Enable the Samsung 8-bit 128MB large page NAND chip driver */
#define CFG_NAND_K9F1G08R0A
#define ONE_BIT_ERROR_CORRECT

/*
 * NAND is partitioned:
 * 0x00000000 - 0x0007FFFF  X-Loader 4 copies
 * 0x00080000 - 0x0025FFFF  U-Boot Image
 * 0x00260000 - 0x0029FFFF  U-Boot Env Data (X-loader doesn't care)
 * 0x002A0000 - 0x0069FFFF  Kernel Image
 * 0x006A0000 - 0x08000000  root filesystem
 */
#define NAND_UBOOT_START         0x0080000 /* first 4 blocks for x-loader */
#define NAND_UBOOT_END           0x0100000 /* 4 blocks, 512KB */
#define NAND_BLOCK_SIZE          0x20000

#define GPMC_CONFIG              (OMAP34XX_GPMC_BASE+0x50)
#define GPMC_NAND_COMMAND_0      (OMAP34XX_GPMC_BASE+0x7C)
#define GPMC_NAND_ADDRESS_0      (OMAP34XX_GPMC_BASE+0x80)
#define GPMC_NAND_DATA_0         (OMAP34XX_GPMC_BASE+0x84)

#ifdef ECC_HW_ENABLE
/* ECC values brought over from u-boot to support hw ecc read */
#define ECCCLEAR        (0x1 << 8)
#define ECCRESULTREG1   (0x1 << 0)
#define ECCSIZE512BYTE  0xFF
#define ECCSIZE1        (ECCSIZE512BYTE << 22)
#define ECCSIZE0        (ECCSIZE512BYTE << 12)
#define ECCSIZE0SEL     (0x000 << 0)
#endif

#ifdef NAND_16BIT
#define WRITE_NAND_COMMAND(d, adr) \
	do {*(volatile u16 *)GPMC_NAND_COMMAND_0 = d;} while(0)
#define WRITE_NAND_ADDRESS(d, adr) \
	do {*(volatile u16 *)GPMC_NAND_ADDRESS_0 = d;} while(0)
#define WRITE_NAND(d, adr) \
	do {*(volatile u16 *)GPMC_NAND_DATA_0 = d;} while(0)
#define READ_NAND(adr) \
	(*(volatile u16 *)GPMC_NAND_DATA_0)
#else /* to support 8-bit NAND devices */
#define WRITE_NAND_COMMAND(d, adr) \
	do {*(volatile u8 *)GPMC_NAND_COMMAND_0 = d;} while(0)
#define WRITE_NAND_ADDRESS(d, adr) \
	do {*(volatile u8 *)GPMC_NAND_ADDRESS_0 = d;} while(0)
#define WRITE_NAND(d, adr) \
	do {*(volatile u8 *)GPMC_NAND_DATA_0 = d;} while(0)
#define READ_NAND(adr) \
	(*(volatile u8 *)GPMC_NAND_DATA_0);
#endif

#define NAND_WAIT_READY()
#define NAND_WP_OFF()  \
	do {*(volatile u32 *)(GPMC_CONFIG) |= 0x00000010;} while(0)
#define NAND_WP_ON()  \
	do {*(volatile u32 *)(GPMC_CONFIG) &= ~0x00000010;} while(0)

#define NAND_CTL_CLRALE(adr)
#define NAND_CTL_SETALE(adr)
#define NAND_CTL_CLRCLE(adr)
#define NAND_CTL_SETCLE(adr)
#define NAND_DISABLE_CE()
#define NAND_ENABLE_CE()

#define DEBUG_LED		186	/* gpio 186 */

/*
 * Board OneNAND info stubs - OneNAND is never used on CM-T3X boards
 */
#define ONENAND_BASE		ONENAND_MAP	/* OneNand flash */
#define ONENAND_ADDR		ONENAND_BASE	/* phys addr of OneNAND at CS0*/
#define ONENAND_START_BLOCK	4
#define ONENAND_END_BLOCK	18
#define ONENAND_PAGE_SIZE	2048		/* 2KB */
#define ONENAND_BLOCK_SIZE	0x20000		/* 128KB */

#endif /* __CONFIG_H */

